#!/bin/bash

# mapWOC
#
# Description: mapwoc-scan.sh - Bash-Shell script to create and start a scan
#                               using curl and mapwocgui.
#
# Authors:
# Felix Wolfsteller <felix.wolfsteller@intevation.de>
#
# Copyright:
# Copyright (C) 2012 Bundesamt für Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

# TODO Force user/pass specification via file to prevent exposure via
#      ps and similars.

# Print usage and dont exit.
usage(){
  echo ""
  cat << EOF
usage: $0 options

This script uses curl to send requests to mapwocgui to define and
start a scan.

All parameters (except -h) are mandatory.
The GUI is expected to deliver english messages and to be in version 1.2 .

OPTIONS:
   -h      Show this message
   -f      URL list file
   -p      Users password
   -s      Server address (and port, if necessary)
   -u      User name
EOF
}


# Parse options.
while getopts ":s:hu:p:f:" opt; do
  case $opt in
    s)
      SERVER="$OPTARG"
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
    :)
      echo "Option -$OPTARG requires an argument." >&2
      exit 1
      ;;
    h)
      usage
      exit 0
      ;;
    p)
      PASS="$OPTARG"
      ;;
    u)
      USER="$OPTARG"
      ;;
    f)
      URLLIST_FILE="$OPTARG"
      ;;
  esac
done

# Check all needed parameters are given.
if [[ -z $SERVER ]] || [[ -z $URLLIST_FILE ]] || [[ -z $USER ]] || [[ -z $PASS ]]
then
  usage
  exit 1
fi

[[ -f $URLLIST_FILE ]] || {
  echo "URL list file $URLLIST_FILE not found.";
  exit 2;
}

COOKIE_FILE=mapwoc.cookies

curl --silent -c $COOKIE_FILE --insecure \
     --data-urlencode "username=$USER" --data-urlencode "password=$PASS" \
     --data-urlencode "submit=Sign In" \
     $SERVER/signin -o mapwoc-scan.signin.response

if [ $? -gt 0 ]
then
  echo "Failed to curl the signin." >& 2
  exit 3;
fi

grep -q "You are now signed in" mapwoc-scan.signin.response || { 
  echo "Login failed.";
  exit 4;
}

NAMEBASE=mapwoc-scan_`md5sum $URLLIST_FILE | cut -f 1 -d " "`

# Upload URL list file
curl --silent -b $COOKIE_FILE -c $COOKIE_FILE --insecure \
     --form URLListFile=@$URLLIST_FILE --form press=Upload%20File \
     --form "URLListUploadName=$NAMEBASE" \
     --form "URLListUploadComment=created with mapwoc-scan" \
     -L \
     $SERVER/urllist/upload -o mapwoc-scan.urllistupload.response

if [ $? -gt 0 ]
then
  echo "Failed to curl the upload." >& 2
  exit 5;
fi

grep -q "Success" mapwoc-scan.urllistupload.response || { 
  echo "URL List upload failed.";
  exit 6;
}

# Get the ID of that url list
#grep "<a href=\"/urllist/view/[0-9]*\">$NAMEBASE" mapwoc-scan.urllistupload.response | tail -n 1 | sed -e 's|.*/\([0-9]\+\)".*|\1|'
# Create Scan Configuration

# TODO post a new scan with the given options. Instead of fetching the ID as in uncommented
#      code above, look at the scan/create page and fetch the id/value there.
exit 0;
